/* SimpsonsSpotGame - File: BehaviorAnimated.m
 *
 * Copyright (C) 31/10/11  Jonathan Pinto Sperafico
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#import "BehaviorAnimated.h"

@implementation BehaviorAnimated

-(void)beginBehavior:(UIImageView *)parent
{
    //Describle the Width and Hight of the view avaliable to deslocate the 2D object
    float viewWidth = 320;
    float viewHeight = 360;
    
    
    //Draw with the boundaries describle above to set the coordenates of the arriving point.
    float x = random() % (int)(viewWidth - parent.frame.size.width);
    float y = random() % (int)(viewHeight - parent.frame.size.height);
    
    //Declare the begin of some animation in the UIView context, in this case the (Donut) parent.
    [UIView beginAnimations:@"BeginAnimated" context:parent];
    
    //Set the delete object the parent him self.
    [UIView setAnimationDelegate:parent];
    
    //YOU MUST SET THIS STOP SELECTOR IN CASE TO KNOW IF THE 2D OBJECT IS ALIVE OR NOT
    [UIView setAnimationDidStopSelector:@selector(warnningFinishedAnimation:finished:context:)];
    
    //Following with the animation duration and the time curve of the animation. It may run faster in the end of the animation.
    [UIView setAnimationDuration:3];
    [UIView setAnimationCurve:UIViewAnimationCurveEaseIn];
    
    //Modify the shape of the UIView correspondent to the end of the animation.
    [parent setFrame:CGRectMake(x + (parent.frame.size.width/2), y + (parent.frame.size.height/2), 30, 30)];
    //And finally commit and release the data to start the animation.
    [UIView commitAnimations];
}

-(void)touchedBehavior:(UIImageView *)parent
{
    //Clean the picture of the UIView and afterwords allocate and set the sprite sequence of the animation.
    parent.image = nil;
    
	NSArray * imageArray  = [[NSArray alloc] initWithObjects:
                             [UIImage imageNamed:@"donut1.png"],
                             [UIImage imageNamed:@"donut2.png"],
                             [UIImage imageNamed:@"donut3.png"],
                             [UIImage imageNamed:@"donut4.png"],
                             [UIImage imageNamed:@"donut5.png"],
                             nil];
	parent.animationImages = imageArray;
    [imageArray release];
    
    //Set the animation duration of the sprites outside of an "UIView beginAnimations" or make it in another "UIView beginAnimations", different of the shape changing.
    parent.animationDuration = 0.4;
    
    //Start the animation
    [parent startAnimating];
    
    //Declare the begin of some animation in the UIView context, in this case the (Donut) parent.
    [UIView beginAnimations:@"EndAnimated" context:parent];
    
    //Following with the animation duration.
    [UIView setAnimationDuration:0.8];
    
    //Set the delete object the parent him self.
    [UIView setAnimationDelegate:parent];
    
    //YOU MUST SET THIS STOP SELECTOR IN CASE TO KNOW IF THE 2D OBJECT IS ALIVE OR NOT
    [UIView setAnimationDidStopSelector:@selector(warnningFinishedAnimation:finished:context:)];
    
    //Set the shape of the 2D Object in the end of the animation. 
    CGRect frame = parent.frame;
    frame.origin.x += frame.size.width / 2;
    frame.origin.y += frame.size.height / 2;
    frame.size.width = 10;
    frame.size.height = 10;
    [parent setFrame:frame];
    [parent setAlpha:0.0];
    
    //And finally commit and release the data to start the animation.
    [UIView commitAnimations];
    
}

@end
