/* SimpsonsSpotGame - File: BehaviorMultiply.m
 *
 * Copyright (C) 01/11/11  Jonathan Pinto Sperafico
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#import "BehaviorMultiply.h"
#import "Gameplay.h"

@implementation BehaviorMultiply

-(void)beginBehavior:(UIImageView *)parent
{
    //Describle the Width and Hight of the view avaliable to deslocate the 2D object
    float viewWidth = 320;
    float viewHeight = 360;
    
    //Draw with the boundaries describle above to set the coordenates of the arriving point.
    float x = random() % (int)(viewWidth - parent.frame.size.width);
    float y = random() % (int)(viewHeight - parent.frame.size.height);
    
    //Declare the begin of some animation in the UIView context, in this case the (Donut) parent.
    [UIView beginAnimations:@"BeginMultiply" context:parent];
    
    //Set the delete object the parent him self.
    [UIView setAnimationDelegate:parent];
    
    //YOU MUST SET THIS STOP SELECTOR IN CASE TO KNOW IF THE 2D OBJECT IS ALIVE OR NOT
    [UIView setAnimationDidStopSelector:@selector(warnningFinishedAnimation:finished:context:)];
    
    //Following with the animation duration and the time curve of the animation. It may run faster in the end of the animation.
    [UIView setAnimationDuration:2];
    [UIView setAnimationCurve:UIViewAnimationCurveEaseIn];
    
    //Modify the shape of the UIView correspondent to the end of the animation.
    [parent setFrame:CGRectMake(x + (parent.frame.size.width/2), y + (parent.frame.size.height/2), 40, 40)];
    
    //And finally commit and release the data to start the animation.
    [UIView commitAnimations];
}

-(void)touchedBehavior:(UIImageView *)parent
{
    //Utilize the singleton of the Gameplay to add a different score for each behavior.
    [[Gameplay getInstance] addScore:20];
    
    //Declare the begin of some animation in the UIView context, in this case the (Donut) parent.
    [UIView beginAnimations:@"EndMultiply" context:parent];
    
    //Following with the animation duration.
    [UIView setAnimationDuration:0.1];
    
    //Set the delete object the parent him self.
    [UIView setAnimationDelegate:parent];
    
    //YOU MUST SET THIS STOP SELECTOR IN CASE TO KNOW IF THE 2D OBJECT IS ALIVE OR NOT
    [UIView setAnimationDidStopSelector:@selector(warnningFinishedAnimation:finished:context:)];
    
    [parent setAlpha:0.0];
    
    //And finally commit and release the data to start the animation.
    [UIView commitAnimations];
    
}

@end
