/* SimpsonsSpotGame - File: Donut.m
 *
 * Copyright (C) 19/10/11  Jonathan Pinto Sperafico
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#import "Donut.h"

@implementation Donut

@synthesize behavior;
@synthesize touched;

-(id) initWithImage:(UIImage *)image Frame:(CGRect)frame andBehavior:(Behavior *)bh;
{
    [super initWithImage:image];
    [self setFrame:frame];
    
    touched = false;
    
    behavior = bh;
    
    //Give to the Donut a time to bem fully initialized and then initialize the behavior
    [behavior performSelector:@selector(beginBehavior:)
               withObject:self
               afterDelay:0.01];
    
    return self;
}

-(void) applyTouchedAnimation
{
    touched = true;
    
    //Send to the correspondent entity to start the touched behavior
    [behavior touchedBehavior:self];
}


-(void) warnningFinishedAnimation:(NSString *)animationID finished:(BOOL)finished context:(void *)context
{
    
    if( [[Gameplay getInstance] isGameOver] )
        return;
    
    //The following part can be put in each behavior and otherwise the if's chain, you can just place [behavior finishCurrentAnimation]; Remember you must create a default method on Behavior Class called finishCurrentAnimation
    if (animationID == @"EndMultiply")
    {
        [[Gameplay getInstance] addNewSpotFrom:self withBehavior:[[BehaviorRotation alloc] init]];
        [[Gameplay getInstance] addNewSpotFrom:self withBehavior:[[BehaviorRotation alloc] init]];
        [[Gameplay getInstance] addNewSpotFrom:self withBehavior:[[BehaviorRotation alloc] init]];
        
        [[Gameplay getInstance] removeSpot:self];
        
    }
    else if(animationID == @"EndRotation")
    {
        //Garantee the maximum of the Donut in the View to 3 or 4 depending of the situation
        [[Gameplay getInstance] removeSpot:self];
    }
    else if(animationID == @"EndSimple")
    {
        
        [[Gameplay getInstance] removeSpot:self];
        [[Gameplay getInstance] addNewSpot:[[BehaviorSimple alloc] init]];
    } 
    
    if ([animationID rangeOfString:@"Begin"].location != NSNotFound && touched == false)
    {
        
        if(animationID == @"BeginRotation")
        {
            [[Gameplay getInstance] removeSpot:self];
        }
        else
        {
            [[Gameplay getInstance] playDisappear];
            
            if ([[Gameplay getInstance] getLifeCount] == 0)
            {
                [[Gameplay getInstance] setEndGame];
            }
            else
            {
                [[Gameplay getInstance] removeLife];
                [[Gameplay getInstance] removeSpot:self];
                [[Gameplay getInstance] addNewSpot:[[BehaviorSimple alloc] init]];
            }
        }
    }
    
}

@end
