/* SimpsonsSpotGame - File: Gameplay.h
 *
 * Copyright (C) 20/10/11  Jonathan Pinto Sperafico
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#import <UIKit/UIKit.h>
#import <CoreGraphics/CGBase.h>
#import <QuartzCore/CoreAnimation.h>
#import <AVFoundation/AVFoundation.h>

#import "Donut.h"

#import "Behavior.h"
#import "BehaviorAnimated.h"
#import "BehaviorMultiply.h"
#import "BehaviorRotation.h"
#import "BehaviorSimple.h"

#import "MyViewController.h"

@class Behavior;
@class MyViewController;
@class Donut;

@interface Gameplay : NSObject
{

    MyViewController *viewController;
    
    NSMutableArray *spots;
    NSMutableArray *lives;
    
    AVAudioPlayer *backgroundPlayer;
    AVAudioPlayer *hitPlayer;
    AVAudioPlayer *missPlayer;
    AVAudioPlayer *disappearPlayer;
    
    int spotsTouched;
    int score;
    int level;
    
    //Surprize element is ready to enter in the game?
    BOOL surprize;
    BOOL gameOver;
    
}

@property (nonatomic, retain) MyViewController *viewController;

//Public method to return the singleton
+(Gameplay*)getInstance;

//Reset the game
-(void) resetGame;

//Garantee the creation of the new spot in the same place than the oldest
-(void) addNewSpotFrom:(Donut *)spot withBehavior:(Behavior *)behavior;

//Create a new spot in a random place
-(void) addNewSpot:(Behavior *)behavior;

//Analize the touch array
-(void) touchesBegan:(NSSet *)touches withEvent:(UIEvent *)event;

//If some touch in the above array is over a Donut, this function is called
-(void) touchedSpot:(UIImageView *)spot;

//Increase the current score amount
-(void) addScore:(int)amount;

//Return the information if the game is over
-(BOOL)isGameOver;

//Play the Sound Effect Desappear
-(void)playDisappear;

//Remove the spot from the array
-(void)removeSpot:(Donut *)spot;

//Remove 1 life of the player
-(void)removeLife;

//Get the amount of lives of the player
-(int)getLifeCount;

//Set the end of the game
-(void)setEndGame;

@end
